/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sshd.server.auth.password;

import org.apache.sshd.server.session.ServerSession;

/**
 * Used to authenticate users based on a password.
 *
 * @author <a href="mailto:dev@mina.apache.org">Apache MINA SSHD Project</a>
 */
@FunctionalInterface
public interface PasswordAuthenticator {
    /**
     * Check the validity of a password.
     *
     * @param username The username credential
     * @param password The provided password
     * @param session  The {@link ServerSession} attempting the authentication
     * @return {@code true} indicating if authentication succeeded
     * @throws PasswordChangeRequiredException If the password is expired or
     * not strong enough to suit the server's policy
     */
    boolean authenticate(String username, String password, ServerSession session) throws PasswordChangeRequiredException;
}
